==> 1.10.1.zip: entaxy-public/ui/entaxy-hawtio/entaxy-management-plugin/src/main/webapp/plugin/js/components/inputs/xml.js <==
/*-
 * ~~~~~~licensing~~~~~~
 * entaxy-management-plugin
 * ==========
 * Copyright (C) 2020 - 2024 EmDev LLC
 * ==========
 * You may not use this file except in accordance with the License Terms of the Copyright
 * Holder located at: https://entaxy.ru/eula . All copyrights, all intellectual property
 * rights to the Software and any copies are the property of the Copyright Holder. Unless
 * it is explicitly allowed the Copyright Holder, the User is prohibited from using the
 * Software for commercial purposes to provide services to third parties.
 * 
 * The Copyright Holder hereby declares that the Software is provided on an "AS IS".
 * Under no circumstances does the Copyright Holder guarantee or promise that the
 * Software provided by him will be suitable or not suitable for the specific purposes
 * of the User, that the Software will meet all commercial and personal subjective
 * expectations of the User, that the Software will work properly, without technical
 * errors, quickly and uninterruptedly.
 * 
 * Under no circumstances shall the Copyright Holder or its Affiliates is not liable
 * to the User for any direct or indirect losses of the User, his expenses or actual
 * damage, including, downtime; loss of bussines; lost profit; lost earnings; loss
 * or damage to data, property, etc.
 * ~~~~~~/licensing~~~~~~
 */
var Entaxy;
(function (Entaxy) {
    Entaxy._module
    .component('entaxyXml', {
        bindings: {
            ngModel: '=',
            mode: '<',
            readonly: '<',
            formController: '<'
        },
        template:
        `
          <button class="entaxy-xml-form" ng-click="$ctrl.openEditor()" ng-disabled="$ctrl.disabled">
            {{$ctrl.buttonTitle}}
          </button>
        `,
        controller: entaxyXmlController
    })
    .name;

    function entaxyXmlController(workspace, $scope, $uibModal) {
        'ngInject';

        let ctrl = this;

        $scope.$watch('$ctrl.readonly', function () {
            ctrl.buttonTitle = ctrl.readonly ? Entaxy.MODAL_MODES.VIEW : ctrl.mode;
            ctrl.disabled = ctrl.readonly &&
                (ctrl.ngModel === undefined || (angular.isString(ctrl.ngModel) && ctrl.ngModel.trim().length === 0));
        });

        ctrl.openEditor = function() {

            $uibModal.open({
                component: 'entaxyXmlModal',
                resolve: {
                    xml: () => ctrl.ngModel,
                    mode: () => ctrl.readonly ? Entaxy.MODAL_MODES.VIEW : ctrl.mode
                },
                size: 'xl',
                backdrop: 'static',
                windowTopClass: 'modal-top-margin-override'
            })
            .result.then(xml => {
                if (ctrl.ngModel !== xml && ctrl.formController && !ctrl.formController.$dirty) {
                    ctrl.formController.$setDirty();
                }
                ctrl.ngModel = xml;
            });
        }
    }
    entaxyXmlController.$inject = ['workspace', '$scope', '$uibModal'];

})(Entaxy || (Entaxy = {}));

==> 1.11.0.zip: entaxy-public/ui/entaxy-hawtio/entaxy-management-plugin/src/main/webapp/plugin/js/components/inputs/xml.js <==
/*-
 * ~~~~~~licensing~~~~~~
 * entaxy-management-plugin
 * ==========
 * Copyright (C) 2020 - 2025 EmDev LLC
 * ==========
 * You may not use this file except in accordance with the License Terms of the Copyright
 * Holder located at: https://entaxy.ru/eula . All copyrights, all intellectual property
 * rights to the Software and any copies are the property of the Copyright Holder. Unless
 * it is explicitly allowed the Copyright Holder, the User is prohibited from using the
 * Software for commercial purposes to provide services to third parties.
 * 
 * The Copyright Holder hereby declares that the Software is provided on an "AS IS".
 * Under no circumstances does the Copyright Holder guarantee or promise that the
 * Software provided by him will be suitable or not suitable for the specific purposes
 * of the User, that the Software will meet all commercial and personal subjective
 * expectations of the User, that the Software will work properly, without technical
 * errors, quickly and uninterruptedly.
 * 
 * Under no circumstances shall the Copyright Holder or its Affiliates is not liable
 * to the User for any direct or indirect losses of the User, his expenses or actual
 * damage, including, downtime; loss of bussines; lost profit; lost earnings; loss
 * or damage to data, property, etc.
 * ~~~~~~/licensing~~~~~~
 */
var Entaxy;
(function (Entaxy) {
    Entaxy._module
    .component('entaxyXml', {
        bindings: {
            ngModel: '=',
            mode: '<',
            readonly: '<',
            setFocused: '<',
            formController: '<'
        },
        template:
        `
          <button class="btn-std entaxy-xml-form" ng-click="$ctrl.openEditor()" ng-disabled="$ctrl.disabled"
                set-focused="$ctrl.setFocused">
            {{$ctrl.buttonTitle}}
          </button>
        `,
        controller: entaxyXmlController
    })
    .name;

    function entaxyXmlController(workspace, $scope, $uibModal) {
        'ngInject';

        let ctrl = this;

        $scope.$watch('$ctrl.readonly', function () {
            ctrl.buttonTitle = ctrl.readonly ? Entaxy.MODAL_MODES.VIEW : ctrl.mode;
            ctrl.disabled = ctrl.readonly &&
                (ctrl.ngModel === undefined || (angular.isString(ctrl.ngModel) && ctrl.ngModel.trim().length === 0));
        });

        ctrl.openEditor = function() {

            $uibModal.open({
                component: 'entaxyXmlModal',
                resolve: {
                    xml: () => ctrl.ngModel,
                    mode: () => ctrl.readonly ? Entaxy.MODAL_MODES.VIEW : ctrl.mode
                },
                size: 'xl',
                backdrop: 'static',
                windowTopClass: 'modal-top-margin-override'
            })
            .result.then(xml => {
                if (ctrl.ngModel !== xml && ctrl.formController && !ctrl.formController.$dirty) {
                    ctrl.formController.$setDirty();
                }
                ctrl.ngModel = xml;
            });
        }
    }
    entaxyXmlController.$inject = ['workspace', '$scope', '$uibModal'];

})(Entaxy || (Entaxy = {}));
